==> mysql-connector-java-6.0.4-sources.jar: com/mysql/cj/mysqla/io/TimeTrackingPacketSender.java <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.mysqla.io;

import java.io.IOException;

import com.mysql.cj.api.io.PacketSender;
import com.mysql.cj.api.io.PacketSentTimeHolder;

/**
 * A {@link PacketSender} which tracks the last time a packet was sent.
 */
public class TimeTrackingPacketSender implements PacketSender, PacketSentTimeHolder {
    private PacketSender packetSender;
    private long lastPacketSentTime = 0;

    public TimeTrackingPacketSender(PacketSender packetSender) {
        this.packetSender = packetSender;
    }

    public void send(byte[] packet, int packetLen, byte packetSequence) throws IOException {
        this.packetSender.send(packet, packetLen, packetSequence);

        this.lastPacketSentTime = System.currentTimeMillis();
    }

    public long getLastPacketSentTime() {
        return this.lastPacketSentTime;
    }
}

==> mysql-connector-java-6.0.5-sources.jar: com/mysql/cj/mysqla/io/TimeTrackingPacketSender.java <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.mysqla.io;

import java.io.IOException;

import com.mysql.cj.api.io.PacketSentTimeHolder;
import com.mysql.cj.api.mysqla.io.PacketSender;

/**
 * A {@link PacketSender} which tracks the last time a packet was sent.
 */
public class TimeTrackingPacketSender implements PacketSender, PacketSentTimeHolder {
    private PacketSender packetSender;
    private long lastPacketSentTime = 0;

    public TimeTrackingPacketSender(PacketSender packetSender) {
        this.packetSender = packetSender;
    }

    public void send(byte[] packet, int packetLen, byte packetSequence) throws IOException {
        this.packetSender.send(packet, packetLen, packetSequence);

        this.lastPacketSentTime = System.currentTimeMillis();
    }

    public long getLastPacketSentTime() {
        return this.lastPacketSentTime;
    }

    @Override
    public PacketSender undecorateAll() {
        return this.packetSender.undecorateAll();
    }

    @Override
    public PacketSender undecorate() {
        return this.packetSender;
    }
}
